using System;
using System.Collections.Generic;
using System.IO;
using UnityEngine;
using UnityEngine.Events;
using UnityEngine.SceneManagement;
using System.Reflection;
using System.Collections;
using System.Threading.Tasks;

namespace MapResizer
{
    public class Mod
    {
        public static void OnLoad()
        {
            ModAPI.RegisterInput("[Map Resizer] Increase map", "increaseMap", KeyCode.K);
            ModAPI.RegisterInput("[Map Resizer] Reduce map", "reduceMap", KeyCode.L);
        }
        public static void Main()
        {
            ModAPI.Register<MapResizeBehaviour>();
        }
    }
    public class MapResizeBehaviour : MonoBehaviour
    {
        public CameraControlBehaviour controlBehaviour;

        public Vector3 min;
        public Vector3 max;
        public Vector3 center;
        public Vector3 size;
        public float sizeLocal = 1;
        public GameObject mapObject;
        private void Awake()
        {
            controlBehaviour = GameObject.FindObjectOfType<CameraControlBehaviour>();
            mapObject = GameObject.Find("WORLD/MAP");
            min = new Vector3(controlBehaviour.BoundingBox.min.x, controlBehaviour.BoundingBox.min.y, controlBehaviour.BoundingBox.min.z);
            max = new Vector3(controlBehaviour.BoundingBox.max.x, controlBehaviour.BoundingBox.max.y, controlBehaviour.BoundingBox.max.z);
            center = new Vector3(controlBehaviour.BoundingBox.center.x, controlBehaviour.BoundingBox.center.y, controlBehaviour.BoundingBox.center.z);
            size = new Vector3(controlBehaviour.BoundingBox.size.x, controlBehaviour.BoundingBox.size.y, controlBehaviour.BoundingBox.size.z);
        }
        private void Update()
        {
            CalculateAndChangeBoundsMap();
            if (InputSystem.Held("increaseMap"))
            {
                ChangeMapSize(mapObject.transform.localScale.x + (mapObject.transform.localScale.x / 2) * Time.deltaTime);
            }
            if (InputSystem.Held("reduceMap"))
            {
                if (mapObject.transform.localScale.x > 0)
                {
                    ChangeMapSize(mapObject.transform.localScale.x - (mapObject.transform.localScale.x / 2) * Time.deltaTime);
                }
            }
        }
        private void ChangeMapSize(float size)
        {
            sizeLocal = size;
            //controlBehaviour.BoundingBox.extents = controlBehaviour.BoundingBox.extents * size;
            Vector3 sizeVector = new Vector3(size, size, 0);
            mapObject.transform.localScale = sizeVector;
        }
        private void CalculateAndChangeBoundsMap()
        {
            controlBehaviour.BoundingBox.Expand(sizeLocal * 100);
        }
    }
}
